==> echarts-grid-1.0.5.tgz: package/src/views/Test.tsx <==
import * as React from "react";
import * as echarts from "echarts";
import "./Test.less";
import * as ReactDOM from "react-dom";
import * as grid from "../../index";

interface TestProps {

}

interface TestStates {

}

export class Test extends React.PureComponent<TestProps, TestStates> {
    constructor(props: TestProps) {
        super(props);
        this.state = {};
    }

    render() {
        return <div ref="chart" className={"echartContainer"}/>;
    }

    componentDidMount() {
        const instance = echarts.init(ReactDOM.findDOMNode(this.refs.chart) as any);
        const options = grid.init({
            instance,
            fields: ["t1", "t2", "t3", "t4", "t5", "t6"],
            columns: {
                fields: [["t6"]],
                type: "metric",
                splitNumber: 5
            },
            rows: {
                fields: ["t2"],
                type: "dimension",
                splitNumber: 5
            },
            dataset: [
                [12, "def", "category1", "中国", "北京", 30],
                [18, "def2", "category1", "中国", "北京", 90],
                [24, "def", "category2", "中国", "北京", 50],
                [32, "abc", "category2", "中国", "广州", 100]
            ],
            cellWidth: 120,
            cellHeight: 40,
            headerWidth: 80,
            headerHeight: 30,
            canvasWidth: instance.getWidth(),
            canvasHeight: instance.getHeight(),
            seriesOptions: {
                type: "bar",
                itemStyle: {
                    color: "orange"
                }
            },
            xAxisOptions: {
                type: "category",
                axisLabel: {
                    color: "#000",
                },
                axisTick: {
                    lineStyle: {
                        color: "#ccc"
                    }
                },
                axisLine: {
                    lineStyle: {
                        color: "#ccc"
                    }
                }
            },
            yAxisOptions: {
                min: 0,
                max: 120,
                type: "value",
                axisTick: {
                    lineStyle: {
                        color: "#ccc"
                    },
                },
                axisLine: {
                    lineStyle: {
                        color: "#ccc"
                    }
                },
                axisLabel: {
                    color: "#000",
                }
            }
        });
        instance.setOption({
            tooltip: {
                trigger: "axis"
            },
            ...options
        } as any);
        setTimeout(() => {
            instance.resize();
        }, 1000);
    }
}

==> echarts-grid-1.0.6.tgz: package/src/views/Test.tsx <==
import * as React from "react";
import * as echarts from "echarts";
import "./Test.less";
import * as ReactDOM from "react-dom";
import * as grid from "../../index";

interface TestProps {

}

interface TestStates {

}

export class Test extends React.PureComponent<TestProps, TestStates> {
    constructor(props: TestProps) {
        super(props);
        this.state = {};
    }

    render() {
        return <div ref="chart" className={"echartContainer"}/>;
    }

    getRandom() {
        return Math.floor(Math.random() * 100 + 1);
    }

    componentDidMount() {
        const instance = echarts.init(ReactDOM.findDOMNode(this.refs.chart) as any);
        const dataset = [];
        const country = ["中国", "美国"];
        const category = ["北京", "上海", "NewYork"];
        const subway = ["line1", "line2", "line3"];
        for (let i = 0; i < 1000; i++) {
            dataset.push([i, subway[this.getRandom() % 3], "abc" + i, "country" + i % 2, 1000 * (this.getRandom() % 50)]);
        }
        const options = grid.init({
            instance,
            fields: ["t1", "t2", "t3", "t4", "t5"],
            columns: {
                fields: [["t5"]],
                type: "metric",
                splitNumber: 5
            },
            rows: {
                fields: ["t4"],
                type: "dimension",
                splitNumber: 5
            },
            dataset,
            cellWidth: 120,
            cellHeight: 40,
            headerWidth: 80,
            headerHeight: 30,
            canvasWidth: instance.getWidth(),
            canvasHeight: instance.getHeight(),
            seriesOptions: {
                type: "bar",
                itemStyle: {
                    color: "orange"
                }
            },
            xAxisOptions: {
                type: "category",
                axisLabel: {
                    color: "#000",
                },
                axisTick: {
                    lineStyle: {
                        color: "#ccc"
                    }
                },
                axisLine: {
                    lineStyle: {
                        color: "#ccc"
                    }
                }
            },
            yAxisOptions: {
                min: 0,
                max: 220000,
                type: "value",
                axisTick: {
                    lineStyle: {
                        color: "#ccc"
                    },
                },
                axisLine: {
                    lineStyle: {
                        color: "#ccc"
                    }
                },
                axisLabel: {
                    showMinLabel: false,
                    showMaxLabel: false,
                    color: "#000",
                }
            }
        });
        instance.setOption({
            tooltip: {
                trigger: "axis"
            },
            ...options
        } as any);
    }
}
